@@ -21,19 +21,19 @@ PKeys::PKeys( TQWidget *parent, const char *name)
     TQPushButton *okButton  = new TQPushButton(this);
     okButton->setText(i18n("Ok"));
     okButton->setFixedSize(okButton->size());
-    connect( okButton, SIGNAL(clicked()),this, SLOT(ok()) );
+    connect( okButton, TQ_SIGNAL(clicked()),this, TQ_SLOT(ok()) );
     okButton->move(20,210);
 
     TQPushButton *defaultButton  = new TQPushButton(this);
     defaultButton->setText(i18n("Defaults"));
     defaultButton->setFixedSize(defaultButton->size());
-    connect( defaultButton, SIGNAL(clicked()),this, SLOT(defaults()) );
+    connect( defaultButton, TQ_SIGNAL(clicked()),this, TQ_SLOT(defaults()) );
     defaultButton->move(140,210);
 
     TQPushButton *cancelButton  = new TQPushButton(this);
     cancelButton->setText(i18n("Cancel"));
     cancelButton->setFixedSize(cancelButton->size());
-    connect( cancelButton, SIGNAL(clicked()),this, SLOT(reject()) );
+    connect( cancelButton, TQ_SIGNAL(clicked()),this, TQ_SLOT(reject()) );
     cancelButton->move(260,210);
 
     TQFrame *separator = new TQFrame(this);
@@ -57,28 +57,28 @@ PKeys::PKeys( TQWidget *parent, const char *name)
     pixPath = dirs->findResource("appdata", "pics/up.xpm");
     up->setPixmap( TQPixmap(pixPath));
     up->setFixedSize(up->pixmap()->size());
-    connect( up, SIGNAL(clicked()),this, SLOT(butUp()) );
+    connect( up, TQ_SIGNAL(clicked()),this, TQ_SLOT(butUp()) );
     up->move(180, 50);
 
     TQPushButton *down = new TQPushButton(this);
     pixPath = dirs->findResource("appdata", "pics/down.xpm");
     down->setPixmap( TQPixmap(pixPath));
     down->setFixedSize(down->pixmap()->size());
-    connect( down, SIGNAL(clicked()),this, SLOT(butDown()) );
+    connect( down, TQ_SIGNAL(clicked()),this, TQ_SLOT(butDown()) );
     down->move(180, 130);
 
     TQPushButton *left = new TQPushButton(this);
     pixPath = dirs->findResource("appdata", "pics/left.xpm");
     left->setPixmap( TQPixmap(pixPath));
     left->setFixedSize(left->pixmap()->size());
-    connect( left, SIGNAL(clicked()),this, SLOT(butLeft()) );
+    connect( left, TQ_SIGNAL(clicked()),this, TQ_SLOT(butLeft()) );
     left->move(140, 90);
 
     TQPushButton *right = new TQPushButton(this);
     pixPath = dirs->findResource("appdata", "pics/right.xpm");
     right->setPixmap( TQPixmap(pixPath));
     right->setFixedSize(right->pixmap()->size());
-    connect( right, SIGNAL(clicked()),this, SLOT(butRight()) );
+    connect( right, TQ_SIGNAL(clicked()),this, TQ_SLOT(butRight()) );
     right->move(220, 90);
 
 
