@@ -402,7 +402,7 @@ void Score::setScore(int level, int player)
         // enable gameNew directly for an immediate next try
         emit gameFinished();
         lastPlayer = -1;
-        TQTimer::singleShot(hallOfFameMS, this, SLOT(end()));
+        TQTimer::singleShot(hallOfFameMS, this, TQ_SLOT(end()));
         return;
     }
 
@@ -514,7 +514,7 @@ void Score::setPause(bool Paused)
 void Score::end()
 {
     if (paused) {
-        TQTimer::singleShot(afterPauseMS, this, SLOT(end()));
+        TQTimer::singleShot(afterPauseMS, this, TQ_SLOT(end()));
         return;
     }
 
